Glances — Glances 3.1.3 documentation

# Glances

Glances is a cross-platform monitoring tool which aims to present a maximum of information in a minimum of space through a curses or Web based interface. It can adapt dynamically the displayed information depending on the terminal size.

It can also work in client/server mode. Remote monitoring could be done via terminal, Web interface or API (XMLRPC and RESTful).

Glances is written in Python and uses the psutil library to get information from your system.

Stats can also be exported to external time/value databases.

# Table of Contents

- Install
- Quickstart
  - Standalone Mode
  - Client/Server Mode
  - Web Server Mode
- Command Reference
  - Command-Line Options
  - Interactive Commands
- Configuration
  - Location
  - Syntax
  - Logging
- Anatomy Of The Application
  - Header
  - Quick Look
  - CPU
  - GPU
  - Load
  - Memory
  - Network
  - Connections
  - Wi-Fi
  - Ports
  - Disk I/O
  - File System
  - Folders
  - IRQ
  - Sensors
  - Processes List
  - Monitored Processes List
  - Applications Monitoring Process
  - events
  - Docker
  - Actions
- Gateway To Other Services
  - CSV
  - Cassandra
  - CouchDB
  - Elasticsearch
  - Graph
  - InfluxDB
  - JSON
  - Kafka
  - MQTT
  - OpenTSDB
  - Prometheus
  - RabbitMQ
  - RESTful
  - Riemann
  - StatsD
  - ZeroMQ
- API Documentation
- Docker
- F.A.Q
- Support